from llama import LLM, setup_config
import unittest

from llama.program.util.config import get_config


class TestConfig(unittest.TestCase):
    def test_config(self):
        llm = LLM(name="test_random", config={"production.key": "hiii"})
        config = get_config()

    def test_manual(self):
        setup_config({"production.key": "hiii"})
        config = get_config()



from llama.types.type import Type
from llama.types.context import Context
from llama.program.builder import Builder as LLM
from llama.metrics.compare_equal_metric import CompareEqualMetric
from llama.program.util.config import setup_config




from llama.program.value import Value

from llama.program.util.type_to_dict import value_to_dict

class ReturnOperation(Value):
    def __init__(self, output_value):
        super().__init__(get_type(output_value))
        self._output_value = output_value

    def _to_dict(self):
        if isinstance(self._output_value, tuple):
            output_value = [value_to_dict(value) for value in self._output_value]
        else:
            output_value = value_to_dict(self._output_value)

        return {
            "name": "ReturnOperation",
            "output_value": output_value,
        }

def get_type(output_value):
    if isinstance(output_value, tuple):
        return (value._type for value in output_value)

    return output_value._type
